is_logicalish: Check if an object is logical or numeric with only 0s and 1s

View source: R/is_logicalish.R

is_logicalishR Documentation

Check if an object is logical or numeric with only 0s and 1s

Description

Check if an object is logical or numeric with only 0s and 1s

Usage

is_logicalish(x)

Arguments

x

An R object to check.

Value

A logical value indicating whether x is logical or numeric containing only 0s and 1s.

Author(s)

Michal Burda

Examples

is_logicalish(c(TRUE, FALSE, NA))        # returns TRUE
is_logicalish(c(0, 1, 1, 0, NA))         # returns TRUE
is_logicalish(c(0.0, 1.0, NA))           # returns TRUE
is_logicalish(c(0, 0.5, 1))              # returns FALSE
is_logicalish("TRUE")                    # returns FALSE

nuggets documentation built on March 11, 2026, 5:06 p.m.