| is_nugget | R Documentation |
Check if the given object is a nugget, i.e. an object created by
nugget(). If a flavour is specified, the function returns TRUE only
if the object is a nugget of the given flavour.
Technically, nuggets are implemented as S3 objects. An object is considered
a nugget if it inherits from the S3 class "nugget". It is a nugget of a
given flavour if it inherits from both the specified flavour class and
the "nugget" class.
is_nugget(x, flavour = NULL)
x |
An object to be tested. |
flavour |
Optional character string specifying the required flavour of
the nugget. If |
A logical scalar: TRUE if x is a nugget (and of the specified
flavour, if given), otherwise FALSE.
Michal Burda
nugget()
d <- partition(mtcars, .breaks = 2)
rules <- dig_associations(d, min_support = 0.3)
is_nugget(rules)
is_nugget(rules, "associations")
is_nugget(mtcars)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.