This function generates all possible permutations of the elements in a given
vector x. The result is returned as a matrix, where each row represents a
unique permutation of the input vector.
See also
utils::combn() for combinations of elements.
This function generates all possible permutations of the elements in a given
vector x. The result is returned as a matrix, where each row represents a
unique permutation of the input vector.
utils::combn() for combinations of elements.